#
# spec file for package vdu_controls
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021-2023 Michael Hamilton <michael@actrix.gen.nz>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vdu_controls
Version:        2.1.4
Release:        1.1
Summary:        Visual Display Unit virtual control panel
License:        GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/digitaltrails/vdu_controls
Source0:        https://github.com/digitaltrails/vdu_controls/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  coreutils
BuildRequires:  hicolor-icon-theme
BuildArch:      noarch
%if 0%{?suse_version}
Requires:       ddcutil
Requires:       noto-sans-math-fonts
Requires:       noto-sans-symbols2-fonts
Requires:       python3
Requires:       python3-qt5
Recommends:     ddcutil-service
Recommends:     python3-pyserial
%endif
%if 0%{?fedora_version}
%define ext_man *
Requires:       ddcutil
Requires:       google-noto-sans-math-fonts
Requires:       google-noto-sans-symbols2-fonts
Requires:       python3
Requires:       python3-qt5
Suggests:       python3-pyserial
%endif

%description
vdu_controls is a virtual control panel for externally connected
VDUs (visual display units).  Controls are included for backlight
brightness, and contrast.  vdu_controls uses the ddcutil command
line utility to interact with external displays via VESA Display
Data Channel (DDC) Virtual Control Panel (VCP) standards.

%prep
%autosetup

%build
#Just a placeholder, no build required.

%install
install -d -m 0755 %{buildroot}%{_bindir} \
                   %{buildroot}%{_mandir}/man1/ \
                   %{buildroot}%{_datadir}/applications \
                   %{buildroot}%{_datadir}/%{name}/translations \
                   %{buildroot}%{_datadir}/%{name}/icons \
                   %{buildroot}%{_datadir}/%{name}/sample-scripts \
                   %{buildroot}%{_datadir}/icons/hicolor/256x256/apps
install -m 0755 %{name}.py  %{buildroot}/%{_bindir}/%{name}
install -m 0644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -m 0644 %{name}.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
install -m 0644 icons/* %{buildroot}%{_datadir}/%{name}/icons/
install -m 0644 translations/*.ts %{buildroot}%{_datadir}/%{name}/translations/
install -m 0644 translations/about_*.txt %{buildroot}%{_datadir}/%{name}/translations/
install -m 0755 sample-scripts/* %{buildroot}%{_datadir}/%{name}/sample-scripts/
install -m 0644 docs/_build/man/%{name}.1 %{buildroot}%{_mandir}/man1/

# This script is supposed to work with any python3 - so leave the shebang alone
# %%if 0%{?suse_version}
# %%python3_fix_shebang
# %%endif

%post
ln -s -f %{_datadir}/icons %{_datadir}/%{name}/icons/system-icons

%files
%license LICENSE.md
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/icons
%dir %{_datadir}/%{name}/translations
%dir %{_datadir}/%{name}/sample-scripts
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/%{name}/icons/*
%{_datadir}/%{name}/translations/da_DK.ts
%{_datadir}/%{name}/translations/fr_FR.ts
%{_datadir}/%{name}/translations/de_DE.ts
%{_datadir}/%{name}/translations/cs_CZ.ts
%{_datadir}/%{name}/translations/about_da_DK.txt
%{_datadir}/%{name}/translations/about_fr_FR.txt
%{_datadir}/%{name}/translations/about_de_DE.txt
%{_datadir}/%{name}/translations/about_cs_CZ.txt
%{_datadir}/%{name}/sample-scripts/lux-from-webcam.bash
%{_datadir}/%{name}/sample-scripts/lux-from-webcam.py
%{_datadir}/%{name}/sample-scripts/vlux_meter.py
%ghost %{_datadir}/%{name}/icons/system-icons

# Build service notes:
# 0) Build service page: https://build.opensuse.org/package/show/utilities/vdu_controls
# 1) branch the package (link on left margin of page)
# 2) upload/alter package files in branch (should be the github versions)
# 3) wait for builds to complete
# 4) when OK/finished/happy, submit
# 5) check assigned tasks: self approve submission and opt to remove branch
# 6) check build service page (above) has updated
# 7) wait for propagation to experimental package https://software.opensuse.org/package/vdu_controls
%changelog
* Sun Mar  9 2025 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.1,4
  * Provide a setting for enabling dbus-events - ddcutil-service DPMS and hotplug detection.
  * Default the dbus-event setting to off, which is less troublesome for some VDUs/GPUs/drivers.
* Tue Feb 18 2025 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.1.3
  * Fix the error-dialog option "Ignore-VDU" when ddcutil cannot communicate with a VDU.
  * Avoid abrupt u-turns in automatic brightness, don't reassess the lux level while making an adjustment.
  * Update the EDID-parser to accept the command line output from ddcutil 2.2 (for those not using ddcutil-service).
* Wed Nov 27 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.1.2
  * Replace the Preset-scheduler with an implementation that remains accurate after PC-sleep/hibernation.
  * Fix the day-rollover which was scheduling for the wrong day if triggered at 12:59:59.
  * When performing a set-vcp, don't increment the NVRAM write count if the VDU doesn't respond.
  * When reconfiguring VDU controllers, discard pending VDU VCP changes from previous controllers.
  * Eliminate a potential for deadlock when handling change-events from ddcutil-service.
  * Better handle ddcutil-service unexpected event types (don't raise an error dialog).
  * The main window height will now automatically resize to accommodate the number of controls present.
  * Toggling lux brightness-interpolation now immediately updates the profile-plot to reflect the change.
  * Fix the Lux Dialog, it was turning off interpolation when first constructed.
* Sun Oct 13 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.1.1
  * Removed --dbus-signals-enabled. DBus signals are now always enabled when --dbus-client
    is enabled.
  * Fix the active Preset icon display which was sometimes incorrect after DPMS-sleep or errors.
  * Fix a code regression when handling non-DDC-capable VDUs (fix status=-3020 exception).
  * The About-Window now includes counts of set_vcp/NVRAM-writes for each VDU.
  * Hovering over a VDU-name in the main-window reveals the write count for that VDU.
  * Minor changes to reduce unnecessary work and improve log messages.
* Sat Sep 28 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.1.0
  * Preset transitions have been deprecated.  All presets are now restored instantly no
    matter how they have been set to transition.  The Preset-Dialog controls for assigning
    transitions have been hidden.  All  transition related code may be removed in a future
    version, please contact me or comment on issue #93 if you prefer transitions to be retained.
  * Transitions and related controls can be re-enabled by disabling `protect-nvram` in the
    Settings-Dialog.
  * To avoid unnecessary updates, preset restoration now queries the VDU's existing
    values. This may slow down preset restoration.
  * Lux-metered auto adjustment has been defaulted to 10 minute intervals (up from 5).
  * Color-Preset (VCP code 0x14) has been added to the list of standard controls.
  * Added a VDU Initializer-Preset feature to provide a replacement for dead NVRAM.
    This also provides a way to restore settings not persisted in VDU NVRAM.  A VDU's
    initializer-preset is automatically run if the target VDU is present at startup or
    is subsequently detected. Any preset that has a name that matches a VDU model and
    serial-number will be treated as an Initializer-Preset.
  * The Preset-Dialog now includes a tool-button  to the right of the preset-name entry
    that will create a VDU specific Initializer-Preset.
* Thu Aug 22 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.0.4
  * The About-Dialog now refreshes the ddcutil version info on each invocation.
  * Increased dbus timeout to 10 seconds (in case numerous VDUs or errors slow down VDU detection).
  * Dynamically enable a scroll-area when the main-panel exceeds the available screen height.
* Mon May  6 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.0.3
  * Reduce the number of writes to VDU NVRAM by sliders, spinners, and ambient brightness adjustments.
  * Slider and spin-box controls now only update the VDU when adjustments become slow or stop (when
    the control value remains constant for 0.5 seconds).
  * Spin-Boxes now select the entire text on focus in (enables easier overtyping and decreases VDU updates).
  * Ambient lighting initiated changes in brightness of up to 20%% are applied without any transitional
    steps (plus the existing code ignores updates of less than 10%%).
  * Set the default ambient-light brightness adjustment-interval to 5 minutes.
  * React to DPMS awake signal from ddcutil-service by re-assessing ambient brightness.
  * Simplified locking and conformed to a locking hierarchy/protocol to avoid potential deadlocks.
* Sat Apr 13 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.0.2
  * Added a *refresh* annotation suffix for use with VCP-codes which cause multiple changes.
  * Make manual adjustment of the ambient Light Level more accurate and responsive.
  * Updates are sent to the VDU as sliders are dragged (rather than only on release).
  * Fix exception on monitors that return invalid/unexpected combo-box VCP values.
  * Fix exception on monitors with blank VCP value descriptions.
  * When refresh is pressed, only auto adjust ambient brightness if auto-brightness is enabled.
  * Don't automatically refresh on error, eliminate popup dialog loops.
  * Eliminate deadlocks when exceptions occur.
  * Cleanup the initialisation of the ddcutil-service connection.
  * Add more caveats and limitations to the documentation.
  * Fix manual ambient light slider when light meter is uninitialized.
  * Promote Simple-Non-Continuous values whose metadata exceeds one-byte to two-byte Complex-NC.
* Tue Feb 27 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 2.0.1
  * Fix D-Bus client code for python versions prior to 3.11.
  * Fix infinite-loop when altering an existing FIFO lux-meter in the Lux-Dialog.
  * Fix the refresh of the LuxDialog meter-readout/plot when changing to a new meter.
  * Apply context-aware defaults to the LuxDialog device file-chooser.
  * Improve/fix the handling of displays/laptop-displays that may be detected but lack proper DDC.
  * Force the file-picker to always show devices and FIFOs - it wasn't showing then on some desktops.
* Fri Feb 16 2024 Michael Hamilton <michael@actrix.gen.nz>
- Update to 2.0.0:
  * Added an Ambient-Light-Level slider - one slider for adjusting brightness on all displays.
  * Optionally use ddcutil-service for up to 10x faster DDC response times.
  * Minor tweaks and additional icons for Presets.
* Tue Oct 17 2023 Michael Hamilton <michael@actrix.gen.nz>
- Update to 1.20.0:
  * Added options monochrome-tray and mono-light-tray to enable a monochrome tray-icon (dark and light).
  * Optional $HOME/.config/vdu_controls/tray_icon.svg overrides the normal tray icon.
  * Improved the adjustment of icon/window dimensions by scaling them in respect to the user's default-font height.
  * Remove adjust-for-dpi in favour of the the above which automatically accounts for DPI.
  * When a Preset is transitioning slowly (i.e. not immediately), the UI controls can be used to stop the transition.
  * Considerable internal refactoring of option handling.
* Thu Sep 21 2023 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.12.0:
  * Added an F10_key context menu shortcut to all application windows (KDE accessibility standard).
  * Set icon and pixmap sizes appropriately for Normal and High DPI (controlled by adjust-for-dpi) (issue #63).
  * Icon/device-chooser-dialog: init-time reduced from 30 to 5 seconds for users with large home folders (issue #61).
  * Improvements/Fixes to the vlux_meter.py sample-script and the related vdu_controls FIFO reader.
  * Improved visibility of the app-icon's preset-transitioning indicator and auto-lux indicator.
  * Increased contrast for generated text preset-abbreviation icons.
  * Encode translations in plain text rather than escaped XML (for easier editing).
* Tue Sep 12 2023 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.11.1:
  * Fix Preset text size in tray icon.
  * Fix occasional concurrency lockup issue in lux_metering.
  * Update the Settings Dialog when a new VDU becomes available.
  * Light-metering: show both a lux-auto indicator (an orange "LED") AND the current preset (if any) in the app icon.
  * Fix first time use crash (issue #60).
  * Allow %% in config files by turning off ConfigParser interpolation (issue #60).
* Sat Jun 24 2023 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.11.0:
  * Made vdu_controls ddcutil-2.0-ready.
  * Added support for ddcutil versions earlier than 1.3 (issue #43, #53).
  * Main-Window: added a hide-on-focus-out option to minimize the main window on focus out (issue #57).
  * Main-Window: changed the layout to display brightness and contrast as the first two controls for each VDU.
  * Main-Window: added jump to clicked value to sliders (issue #59).
  * Main-Window: added a smart-main-window option to make main window placement and geometry preservation optional.
  * Main-Window: the main window can now be raised above the other sub-windows (gnome issue only).
  * Main-Window and Context Menu: added alt-key keyboard shortcuts (issue #13).
  * Context-Menu: added an indicator mark suffix to the currently active Preset (if any) (issue #55).
  * Context-Menu: made changes to Preset ordering propagate to the menu without requiring an application restart.
  * Tray-Icon: made the app icon un-themed so that overlaid active Preset text/icon is more visible (issue #55).
  * Settings-Dialog: added a Reset button to makes it possible to un-ignore a VDU (issue #51).
  * Settings-Dialog: added tool-tips to main config-settings, made them consistent with command line help (issue #52).
  * Preset-Dialog: combined the Activate and Edit buttons into one button (simpler and more intuitive).
  * Preset Dialog: made the dialog bold the text button of the currently active Preset (if any).
  * Preset Dialog: added code to detect and and warn of unsaved changes.
  * Preset Dialog: made the dialog lock out any scheduled or automatic VDU changes while a Preset is being edited.
  * Preset-Dialog: supplied a starter set of Prest icons - a selection of KDE breeze5-icons (issue #56).
  * Popup-Messages: made message box popups resizable for increased readability.
  * Command-line: made config-settings and command-line arguments consistent, command line has precedence (issue #52).
  * Command-line: fixed --sleep-multiplier so that it is actually applied (issue #54).
  * Prevented potential crashes in the event of utf-8 decoding errors for EDIDs and capabilities (issue #49).
  * Added logging of stack traces for some errors if debugging is set to on (issue #49).
  * Improved the handling of ddcutil not found (issue #48).
  * Refactored to improve maintainability and run-time efficiency (issue #52).
  * Added Deepin 23 pyqt library compatibility.
  * Numerous minor enhancements and fixes.
  * An alpha release of vlux_meter.py, a system-tray webcam lux-meter, has been included in the sample scripts folder.
* Thu May 11 2023 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.10.2:
  * Fix Preset non-zero transition-step-seconds, so it works properly.
  * Changing log-to-syslog or log-debug-enabled no longer requires a restart.
  * Fix Lux Auto menu icon when starting with Auto disabled.
  * Use the progress bar area on the main panel for status messages.
  * Make auto brightness behave more predictably by removing unnecessary constraints on interpolation.
  * Improve auto-lux/preset tray icon interaction, better reflect actions and current state.
* Thu May  4 2023 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.10.1:
  * Restore lux meter displayed-value when restoring LuxDialog window.
  * Minor fixes to reduce and improve displayed and logged messages.
  * Rollup release prior to downtime for ToTK
* Sun Mar 26 2023 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.10.0:
  * Added hardware lux metering options (GY30/BH1750+Arduino, UNIX-fifo, or executable-script).
  * Added lux-to-brightness profiles per VDU.
  * Added sample scripts for using a webcam to produce approximate lux values.
  * Added an option to transition smoothly on UNIX signal.
  * Replaced the transition combo-box with a button+checkboxes.
  * Added drag-to-change, click-to-delete, to the elevation chart component.
  * Added a setting to quickly disable weather and another for elevation-scheduling.
  * Cleanup of thread handling - clarification of GUI/non-GUI thread operations.
  * Reduced logging and eliminated popup dialogs when monitors are suspended or powered off.
* Sat Feb 18 2023 Michael Hamilton <michael@actrix.gen.nz>
- update to 1.9.2:
  * The Presets Dialog now includes an option to set a Preset to Transition Smoothly.
  * The tray, main panel, and Preset Dialog indicate when a smooth transition is in progress.
  * Transitions are performed by a non-GUI thread, the GUI remains accessible during smooth transitions.
  * A smooth transition can be interrupted by moving the controls being transitioned or invoking a preset.
* Wed Jan 25 2023 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.9.1:
  * Busy spinners and control lockouts applied during refresh and
    preset activation.  Introducing SpinBox input fields. Use EDID.
* Mon Jan 23 2023 malcolmlewis@opensuse.org
- Clean up build in preparation for development repository and
  Factory submission.
* Wed Jan 11 2023 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.9.0:
  * Bug fixes and speedy performance improvements.
* Wed Dec 14 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.8.3:
  * Fix crash when network is down and weather site is not
    contactable.
* Fri Nov 11 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.8.1:
  * Fix daily scheduling of presets.
* Sat Oct 29 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.8.0:
  * New feature, allow presets to be scheduled by solar elevation.
* Mon Sep 26 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.7.2:
  * Better handle monitor being powered off.
  * Allow presets to be reordered on the menu.
* Sun Sep 25 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.7.1:
  * Fix for signal handling from Mark Lowne.
* Thu Aug  4 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.7.0:
  * Display current preset in window and tray title, preset icons.
* Sun Jul 31 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.11:
  * Cleaning up the help and Linux man page.
* Tue Jul 12 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.10:
  * Cope better with transient slider values, cope better with
    session startup delays to detection.
* Mon Jun 13 2022 Michael Hamilton <michael@actrix.gen.nz>
- Update to version 1.6.8:
- Fix preset save/restore bug introduced in 1.6.7.
* Sun Jun 12 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.7:
  * Fix issues with gnome 42.2 tray: when in gnome do as the
    gnomens do.
* Sat Jun 11 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.5:
  * Widen handling of pare exceptions for VDU capabilities - catch
    more exceptions.
* Wed Apr 13 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.4:
  * Wayland wait for system tray at login.
  * Enable HiDPI icons.
* Sun Apr 10 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.3:
  * Added a hamburger menu to provide alternate access to the
    context menu.
* Sat Apr  9 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.2:
  * Add a feature Values: min..max override.
* Mon Mar 14 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.1:
  * Wayland fixes.
* Mon Mar  7 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.6.0:
  * Let other processes trigger preset changes and settings
    refreshes via UNIX/Linux signals.
* Sun Feb 27 2022 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.5.9:
  * Cleanly handle monitors that do not respond to ddcutil
    commands.
* Sat Dec  4 2021 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.5.7:
  * Check if a system tray is available before applying
    system_tray_enabled.
* Sat Nov 13 2021 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.5.5:
  * Fix tray for some desktops.
  * Combobox value enhancements/fixes.
  * Login-restart support/
* Mon Nov  8 2021 Michael Hamilton <michael@actrix.gen.nz>
- Updated to version 1.5.3:
  * Detect and handle light/dark theme changes.
* Mon Oct  4 2021 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.5.2:
  * Packaged for rpm vdu_controls.
